﻿using Infragistics.Web.Mvc;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using WebApplication3.Models;

namespace WebApplication3.Controllers
{
    public class HomeController : Controller
    {
        private SampleViewModel vm
        {
            get
            {
                if (Session["ViewModel"] == null)
                {
                    Session["ViewModel"] = new SampleViewModel();
                }
                return Session["ViewModel"] as SampleViewModel;
            }
        }

        public ActionResult Index()
        {
            return View(vm);
        }

        [HttpPost]
        public ActionResult Index(SampleViewModel changedData)
        {
            /**
             * The SampleViewModel that is passed in as a parameter above contains the current values for
             * all of the form inputs. In this instance it has the current values of TextItem and NumberItem.
             * In addition, it contains the original values for the SampleData.Items collection
             **/
            System.Diagnostics.Debug.WriteLine("TextItem Current Value: " + changedData.TextItem);
            System.Diagnostics.Debug.WriteLine("NumberItem Current Value: " + changedData.NumberItem);

            /**
             * On the form we store the transactions of the grid in a hidden input called ig_transactions.
             * This isn't passed in to this Action as a parameter but it is available as part of the request.
             * The Infragistics GridModel provides a useful method called LoadTransactions which will convert
             * the ig_transactions string in to an array of Transaction<T> objects. From this we can check what
             * the type of the transaction is and apply the correct changes to our data. 
             **/
            GridModel gridModel = new GridModel();
            List<Transaction<DataItem>> transactions = gridModel.LoadTransactions<DataItem>(Request.Form["ig_transactions"]);
            foreach (Transaction<DataItem> transaction in transactions)
            {
                if (transaction.type == "newrow")
                {
                    // row was added
                    System.Diagnostics.Debug.WriteLine(
                        string.Format("Adding row - ID: {0}, Text: {1}, Value {2}, Date {3}",
                        transaction.row.ID,
                        transaction.row.Text,
                        transaction.row.Value,
                        transaction.row.Date
                    ));
                }
                else if (transaction.type == "deleterow")
                {
                    // row was deleted
                    System.Diagnostics.Debug.WriteLine("Deleting row with ID: " + transaction.rowId);
                }
                else if (transaction.type == "row")
                {
                    // row was updated
                    System.Diagnostics.Debug.WriteLine(
                        string.Format("Updating row - ID: {0}, Text: {1}, Value {2}, Date {3}",
                        transaction.row.ID,
                        transaction.row.Text,
                        transaction.row.Value,
                        transaction.row.Date
                    ));
                }
            }

            return View(vm);
        }
    }
}